==> media_twig_tools-1.0.3.tar.gz: media_twig_tools/tests/src/Unit/ImageBuilderTest.php <==
<?php

namespace Drupal\Tests\media_twig_tools\Unit;

use Drupal\Core\Entity\EntityInterface;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Drupal\image\ImageStyleStorage;
use Drupal\media_twig_tools\Config\MediaTwigToolsConfig;
use Drupal\media_twig_tools\Services\ImageBuilder;
use Drupal\Tests\UnitTestCase;

/**
 * Test description.
 *
 * @group media_twig_tools
 */
class ImageBuilderTest extends UnitTestCase {

  /**
   * FIle name.
   *
   * @const string
   */
  const FILE_NAME = 'public://files/test.png';

  /**
   * ImageBuilder.
   *
   * @var \Drupal\media_twig_tools\Services\ImageBuilder
   */
  protected $imageBuilders;

  /**
   * Tests data.
   *
   * @var mixed
   */
  protected $testData = [];

  /**
   * Input File.
   *
   * @var \Drupal\file\Entity\File|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $file;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Init mocks.
    $config = $this->mockConfig();
    $this->file = $this->mockFile();

    // Init image builder.
    $this->imageBuilders = new ImageBuilder($config);

    // Init data to test.
    $json = file_get_contents(__DIR__ . '/../../data/data.json');
    $this->testData = json_decode($json, TRUE);
  }

  /**
   * Tests output file paths.
   */
  public function testOutputFilePath() {
    foreach ($this->testData['tests'] as $data) {
      $this->testData($data, $this->file);
    }
  }

  /**
   * Test data.
   *
   * @param array $data
   *   Input data.
   * @param \Drupal\Core\Entity\EntityInterface $file
   *   The file.
   */
  protected function testData(array $data, EntityInterface $file) {
    $expected = $this->imageBuilders->getImageUrlFromFileAndSettings(
      $file->id(),
      '/sites/default/files/images/test.png',
      $data['settings'],
      $data['src'],
      $data['options'],
      $data['rule'],
    );

    $this->assertEquals(
      $data['expected'],
      $expected
    );
  }

  /**
   * Return the config mock.
   *
   * @return \Drupal\media_twig_tools\Config\MediaTwigToolsConfig|\PHPUnit\Framework\MockObject\MockObject
   *   The mock.
   */
  protected function mockConfig() {
    $conf = $this->getMockBuilder(MediaTwigToolsConfig::class)
      ->disableOriginalConstructor()
      ->getMock();

    $conf->expects($this->any())
      ->method('getDirname')
      ->will($this->returnValue('builder'));

    $conf->expects($this->any())
      ->method('getNoStyle')
      ->will($this->returnValue('landscape'));

    // Init the image style storage mock.
    $imageStyleStorage = $this->getMockBuilder(ImageStyleStorage::class)
      ->disableOriginalConstructor()
      ->getMock();
    $imageStyleStorage->expects($this->any())
      ->method('load')
      ->willReturnCallback(function ($id) {
        $imageStyleMock = $this->getMockBuilder(ImageStyle::class)
          ->disableOriginalConstructor()
          ->getMock();
        $imageStyleMock->expects($this->any())
          ->method('id')
          ->will($this->returnValue($id));

        return $imageStyleMock;
      });

    $conf->expects($this->any())
      ->method('getImageStyleStorage')
      ->will($this->returnValue($imageStyleStorage));

    return $conf;
  }

  /**
   * Mock file.
   *
   * @return \Drupal\file\Entity\File|\PHPUnit\Framework\MockObject\MockObject
   *   The file mock.
   */
  protected function mockFile() {
    // Define file.
    $file = $this->getMockBuilder(File::class)
      ->disableOriginalConstructor()
      ->getMock();
    $file->expects($this->any())
      ->method('id')
      ->will($this->returnValue(1));
    $file->expects($this->any())
      ->method('getFileUri')
      ->will($this->returnValue(static::FILE_NAME));
    return $file;
  }

}

==> media_twig_tools-2.1.0-rc6.tar.gz: media_twig_tools/tests/src/Unit/ImageBuilderTest.php <==
<?php

namespace Drupal\Tests\media_twig_tools\Unit;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\file\Entity\File;
use Drupal\file\FileInterface;
use Drupal\image\Entity\ImageStyle;
use Drupal\image\ImageStyleStorage;
use Drupal\media_twig_tools\Config\MediaTwigToolsConfig;
use Drupal\media_twig_tools\Services\Bounce;
use Drupal\media_twig_tools\Services\ImageBuilder;
use Drupal\Tests\UnitTestCase;
use GuzzleHttp\Client;

/**
 * Test description.
 *
 * @group media_twig_tools
 */
class ImageBuilderTest extends UnitTestCase {

  /**
   * FIle name.
   *
   * @const string
   */
  const FILE_NAME = 'public://files/test.png';

  /**
   * ImageBuilder.
   *
   * @var \Drupal\media_twig_tools\Services\ImageBuilder
   */
  protected ImageBuilder $imageBuilders;

  /**
   * Tests data.
   *
   * @var array
   */
  protected array $testData = [];

  /**
   * Input File.
   *
   * @var \Drupal\file\FileInterface
   */
  protected FileInterface $file;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Init mocks.
    $config = $this->mockConfig();
    $this->file = $this->mockFile();
    $bounce = $this->createMock(Bounce::class);
    $file_url_generator = $this->createMock(FileUrlGeneratorInterface::class);
    $client = $this->createMock(Client::class);

    // Init image builder.
    $this->imageBuilders = new ImageBuilder($config, $bounce, $file_url_generator, $client);

    // Init data to test.
    $json = file_get_contents(__DIR__ . '/../../data/data.json');
    $this->testData = json_decode($json, TRUE);
  }

  /**
   * Tests output file paths.
   */
  public function testOutputFilePath() {
    foreach ($this->testData['tests'] as $data) {
      $this->testData($data, $this->file);
    }
  }

  /**
   * Test data.
   *
   * @param array $data
   *   Input data.
   * @param \Drupal\Core\Entity\EntityInterface $file
   *   The file.
   */
  protected function testData(array $data, EntityInterface $file) {
    $expected = $this->imageBuilders->getImageUrlFromFileAndSettings(
      $file->id(),
      '/sites/default/files/images/test.png',
      $data['settings'],
      $data['src'],
      $data['options'],
      $data['rule'],
    );

    $this->assertEquals(
      $data['expected'],
      $expected
    );
  }

  /**
   * Return the config mock.
   *
   * @return \Drupal\media_twig_tools\Config\MediaTwigToolsConfig|\PHPUnit\Framework\MockObject\MockObject
   *   The mock.
   */
  protected function mockConfig() {
    $conf = $this->createMock(MediaTwigToolsConfig::class);

    $conf->expects($this->any())
      ->method('getDirname')
      ->will($this->returnValue('builder'));

    $conf->expects($this->any())
      ->method('getNoStyle')
      ->will($this->returnValue('landscape'));

    // Init the image style storage mock.
    $imageStyleStorage = $this->createMock(ImageStyleStorage::class);
    $imageStyleStorage->expects($this->any())
      ->method('load')
      ->willReturnCallback(function ($id) {
        $imageStyleMock = $this->createMock(ImageStyle::class);
        $imageStyleMock->expects($this->any())
          ->method('id')
          ->will($this->returnValue($id));

        return $imageStyleMock;
      });

    $conf->expects($this->any())
      ->method('getImageStyleStorage')
      ->will($this->returnValue($imageStyleStorage));

    return $conf;
  }

  /**
   * Mock file.
   *
   * @return \Drupal\file\Entity\File|\PHPUnit\Framework\MockObject\MockObject
   *   The file mock.
   */
  protected function mockFile() {
    // Define file.
    $file = $this->createMock(File::class);
    $file->expects($this->any())
      ->method('id')
      ->will($this->returnValue(1));
    $file->expects($this->any())
      ->method('getFileUri')
      ->will($this->returnValue(static::FILE_NAME));
    return $file;
  }

}
